import pygame as pg
import scipy.stats as ss
import numpy as np
from win32gui import SetWindowPos, SetFocus
import win32con

mu1 = float(input('mu_1 = '))
mu2 = float(input('mu_2 = '))
sgm1 = float(input('sgm_1 = '))
sgm2 = float(input('sgm_2 = '))
n1 = int(input('n_1 = '))
n2 = int(input('n_2 = '))
wt = int(3000 / (n1 + n2)) + 1

pg.init()
pg.display.set_caption('Two Independent Sampling')
screen = pg.display.set_mode(size=(800, 600))
SetWindowPos(pg.display.get_wm_info()['window'], -1, 0, 0, 0, 0,
             win32con.SWP_ASYNCWINDOWPOS | win32con.SWP_NOMOVE |
             win32con.SWP_NOSIZE | win32con.SWP_SHOWWINDOW)

screen.fill((255,255,255))
pg.display.flip()
my_font = pg.font.SysFont(None, 32)
my_font_L = pg.font.SysFont(None, 40)
img_str_L = my_font_L.render('Next -> key N,    End -> key E', True,
                             (0,0,0), (255,255,255))
rect_str_L = img_str_L.get_rect()

my_font_L1 = pg.font.SysFont(None, 60)
img_str_mouse = my_font_L1.render('Click here, twice', True,
                             (0,0,0), (255,255,255))
rect_str_mouse = img_str_mouse.get_rect()
screen.blit(img_str_mouse, (400 - rect_str_mouse.width//2,
                            300 - rect_str_mouse.height//2))
pg.display.flip()
ck1 = True
while ck1:
    for e in pg.event.get():
        if e.type == pg.MOUSEBUTTONDOWN:
            ck1 = False

ck = True
while ck:
    x1 = ss.norm.rvs(mu1, sgm1, n1)
    x2 = ss.norm.rvs(mu2, sgm2, n2)

    min_x = np.min(x1) if np.min(x1) < np.min(x2) else np.min(x2)
    max_x = np.max(x1) if np.max(x1) > np.max(x2) else np.max(x2)

    def scale_x(v):
        return int(30 + 740 * (v - min_x) / (max_x - min_x))

    screen.fill((255,255,255))

    for i in range(n1):
        pg.draw.circle(screen, (0,200,0), (scale_x(x1[i]), 250), 10, 3)
        pg.display.flip()
        pg.time.wait(wt)

    m1_hat = np.mean(x1)
    s1_hat = np.std(x1)
    str1 = f'mu1 = {mu1}, sgm1 = {sgm1},' + \
            f'  m1_hat = {m1_hat:.2f}, s1_hat = {s1_hat:.2f}'
    img_str1 = my_font.render(str1, True, (0,0,0), (255,255,255))
    screen.blit(img_str1, (50, 150))
    
        
    for i in range(n2):
        pg.draw.circle(screen, (0,0,200), (scale_x(x2[i]), 400), 10, 3)
        pg.display.flip()
        pg.time.wait(wt)


    m2_hat = np.mean(x2)
    s2_hat = np.std(x2)
    str2 = f'mu2 = {mu2}, sgm2 = {sgm2},' + \
            f'  m2_hat = {m2_hat:.2f}, s2_hat = {s2_hat:.2f}'
    img_str2 = my_font.render(str2, True, (0,0,0), (255,255,255))
    screen.blit(img_str2, (50, 330))

    r = ss.ttest_ind(x1, x2)                       #   Student
    rw = ss.ttest_ind(x1, x2, equal_var = False)   #   Welch
    strg = f't = {r.statistic:.3f}, p = {r.pvalue:.5f}, df = {r.df:.0f}'
    strgw =  f"t' = {rw.statistic:.3f}, p' = {rw.pvalue:.5f}, df' = {rw.df:.3f}"
    img_strg = my_font.render(strg, True, (0,0,0), (255,255,255))
    screen.blit(img_strg, (400 - (img_strg.get_rect().width//2), 10))
    img_strgw = my_font.render(strgw, True, (0,0,0), (255,255,255))
    screen.blit(img_strgw, (400 - (img_strgw.get_rect().width//2), 40))

    screen.blit(img_str_L, (400 - (rect_str_L.width//2),
                                   600 - (rect_str_L.height*2)) )
    pg.display.flip()

    pg.event.set_grab(True)
    ck1 = True
    while ck1:
        for e in pg.event.get():
            if e.type == pg.KEYDOWN:
                if e.key == pg.K_n:
                    ck1 = False
                elif e.key == pg.K_e:
                    ck = False
                    ck1 = False

pg.quit()
